;; Generated package description from .el  -*- sml-modeno-byte-compile: t -*-
(define-package "sml-mode" "6.12.0.20250404.173928" "Major mode for editing (Standard) ML" '((emacs "24.3") (cl-lib "0.5")) :commit "39ad5243eb761821e5342ed8cf1ba111d2492f48" :url "https://elpa.gnu.org/packages/sml-mode.html" :authors '(("Matthew Morley" . "mjm@scs.leeds.ac.uk") ("Matthias Blume" . "blume@cs.princeton.edu") ("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '("Stefan Monnier" . "monnier@iro.umontreal.ca") :keywords '("sml"))
